__all__ = ["SENTINEL1_COLLECTION_ID", "VV", "VH", "IW", "ASCENDING", "DESCENDING"]

SENTINEL1_COLLECTION_ID = "COPERNICUS/S1_GRD_FLOAT"
VV = "VV"
VH = "VH"
IW = "IW"
ASCENDING = "ASCENDING"
DESCENDING = "DESCENDING"
GEE_PROPERTIES = [
    "system:id",
    "sliceNumber",
    "system:time_start",
    "relativeOrbitNumber_start",
    "relativeOrbitNumber_stop",
    "orbitNumber_start",
    "orbitNumber_stop",
    "instrumentConfigurationID",
    "system:asset_size",
    "cycleNumber",
]
